@@ -48,7 +48,8 @@ _samp_acaml_re = re.compile(
 # prefix regex to deal with irritating prefixed tree names
 _prefix_re = re.compile('(?P<prefix>.+)ACAML')
 # regex to extract timezone from Agilent date time string
-_agilent_dt_re = re.compile('(?P<dt>.+)[-+].+')
+_agilent_dt_re = re.compile('(?P<dt>\d{4}-\d{2}-\d{2}T\d{2}:\d{2}:\d{2}(\.\d{2,6})?)')
+# this regex will only accept down to microseconds and will drop nanoseconds
 
 
 def strptime_agilent_dt(dt_string: str) -> datetime.datetime:
@@ -61,6 +62,7 @@ def strptime_agilent_dt(dt_string: str) -> datetime.datetime:
     observed_formats = [
         '%Y-%m-%dT%H:%M:%S.%f',  # with ms value
         '%Y-%m-%dT%H:%M:%S',  # w/o ms value
+        '%Y-%m-%dT%H:%M:%S.%fZ',  # workstation
     ]
     for fmt in observed_formats:
         try:
@@ -782,6 +784,7 @@ class MSSpectrum(AgilentMS):
         self.chromatogram.columns: np.ndarray = self.chromatogram.columns[sort_array]  # sort mass array
         # todo type hint for csr matrix
         self.chromatogram.values = self.chromatogram.values[:, sort_array]  # rearrange csr matrix for sorted mzs
+        self.file_path = pathlib.Path(self.filename)
 
     def __str__(self):
         return f'{self.__class__.__name__} {self.info["name"]} {self.info["filename"].split(os.sep)[-1]}'
@@ -849,7 +852,7 @@ class MSSpectrum(AgilentMS):
         return self.chromatogram.values.toarray()[start_ind:end_ind].sum(axis=0)
 
     @classmethod
-    def create_from_D_file(cls, file_path: Union[pathlib.Path, str]) -> "MSSpectrum":
+    def create_from_D_file(cls, file_path: Union[pathlib.Path, str]) -> List["MSSpectrum"]:
         """
         Creates a MSSpectrum instance from an Agilent .D file
 
@@ -863,9 +866,10 @@ class MSSpectrum(AgilentMS):
         ms_files = [filename for filename in os.listdir(file_path) if filename.endswith('.MS')]
         # todo catch if multiple MS files (does this happen?)
         try:
-            return cls(
-                os.path.join(file_path, ms_files[0])
-            )
+            return [
+                cls(str(file_path / ms_file))
+                for ms_file in ms_files
+            ]
         except IndexError:
             raise FileNotFoundError(f'no .MS files were found in the target path')
 
@@ -1109,6 +1113,8 @@ class DADSignal(DADSignalInfo):
 
         :return: data table as iterable
         """
+        if self.spectrum is None:
+            raise AttributeError(f'no spectral data is associated with the instance')
         if self.reference is not None:  # if the signal is referenced
             # yield header row
             yield (
@@ -1155,10 +1161,12 @@ class DADSignal(DADSignalInfo):
         # if the file already exists and overwrite was not specified, return
         if os.path.isfile(filename) and overwrite is False:
             return
+        data = "\n".join(
+            ",".join([str(val) for val in line])
+            for line in self.as_iterable_data_table()
+        )
         with open(filename, 'wt') as f:
-            for line in self.as_iterable_data_table():
-                f.write(",".join([str(val) for val in line]))
-                f.write('\n')
+            f.write(data)
         return filename
 
 
@@ -1169,7 +1177,7 @@ class HPLCSample(HPLCSampleInfo):
                  signals: Union[List[DADSignalInfo], List[DADSignal], List[str]],
                  datetimestamp: Union[str, datetime.datetime] = None,
                  dad_spectrum: DADSpectrum = None,
-                 ms_spectrum: MSSpectrum = None,
+                 ms_spectra: List[MSSpectrum] = None,
                  directory: str = None,
                  ):
         """
@@ -1180,6 +1188,7 @@ class HPLCSample(HPLCSampleInfo):
         :param method_name: name of method used to run the sample
         :param signals: list of signals associated with the run
         :param dad_spectrum: DADSpectrum object with loaded data
+        :param ms_spectra: list of mass spectra
         :param directory: directory path where the sample may be found
         """
         HPLCSampleInfo.__init__(
@@ -1190,7 +1199,7 @@ class HPLCSample(HPLCSampleInfo):
             datetimestamp=datetimestamp
         )
         self.spectrum: DADSpectrum = dad_spectrum
-        self.ms_spectrum: MSSpectrum = ms_spectrum
+        self.ms_spectra: List[MSSpectrum] = ms_spectra or []
         self.signals = [DADSignal.create_from_DADSignalInfo(signal, self.spectrum) for signal in self.signals]
         self.directory = directory
 
@@ -1212,13 +1221,13 @@ class HPLCSample(HPLCSampleInfo):
         except FileNotFoundError:
             dad_spectrum = None
         try:
-            ms_spectrum = MSSpectrum.create_from_D_file(file_path)
+            ms_spectra = MSSpectrum.create_from_D_file(file_path)
         except FileNotFoundError:
-            ms_spectrum = None
+            ms_spectra = None
         return cls(
             **sample_info_values,
             dad_spectrum=dad_spectrum,
-            ms_spectrum=ms_spectrum,
+            ms_spectra=ms_spectra,
             directory=file_path,
         )
 
@@ -1291,16 +1300,19 @@ class HPLCSample(HPLCSampleInfo):
         # write TAC
         tac_file_name = directory / 'Total Absorbance Chromatogram.csv'
         written_paths.append(str(tac_file_name))
+        tac_data = "\n".join(
+            f"{rt},{intensity}"
+            for rt, intensity in zip(
+                self.spectrum.retention_times,
+                self.spectrum.total_absorbance_chromatogram,
+            )
+        )
         with open(tac_file_name, 'wt') as f:
             f.write(
-                f'Retention Time (min),'  
-                f'Total Absorbance Chromatogram ({self.spectrum.chromatogram.yunits}),\n'
+                f'Retention Time (min),'
+                f'Total Absorbance Chromatogram ({self.spectrum.chromatogram.yunits})\n'
             )
-            for rt, intensity in zip(
-                    self.spectrum.retention_times,
-                    self.spectrum.total_absorbance_chromatogram
-            ):
-                f.write(f'{rt},{intensity},\n')
+            f.write(tac_data)
         return written_paths
 
     def write_signals_to_xlsx(self, output_file: Union[str, pathlib.Path] = None) -> str:
