@@ -1,7 +1,8 @@
 import re
-import os
 from openpyxl import Workbook
 import warnings
+from typing import Union
+import pathlib
 
 # separator line
 _header_block_re = re.compile(
@@ -193,7 +194,7 @@ def pull_hplc_area(filename):
     return pull_hplc_area_from_txt(filename)
 
 
-def report_text_to_xlsx(target_file: str, output_file: str = None) -> str or None:
+def report_text_to_xlsx(target_file: Union[str, pathlib.Path], output_file: Union[str, pathlib.Path] = None) -> str or None:
     """
     Ingests the specified report text and outputs it to an excel file.
 
@@ -207,8 +208,13 @@ def report_text_to_xlsx(target_file: str, output_file: str = None) -> str or Non
     except ValueError:    # No peaks in Report.txt
         raise ValueError(f'There were no peaks found in the target file "{target_file}"')
 
+    if isinstance(target_file, pathlib.Path) is False:
+        target_file = pathlib.Path(target_file)
+    if target_file.is_absolute() is False:
+        target_file = target_file.absolute()
+
     if output_file is None:
-        output_file = f'{os.path.dirname(target_file)}\\Report.xlsx'
+        output_file = target_file.parent / 'Report.xlsx'
 
     excel = Workbook()
     # ordered list of keys to write
