@@ -25,6 +25,9 @@ class AcquisitionSearch:
 
     instances: List['AcquisitionSearch'] = []
 
+    _multi_warn = False  # warning flag for multiple acquiring matches
+    _monitor_thread: threading.Thread = None
+
     # flag to indicate whether the "start all monitors" flag has been set
     _all_started: bool = False
 
@@ -59,12 +62,15 @@ class AcquisitionSearch:
         self._monitor_thread = threading.Thread(
             target=self._acquiring_monitor,
             daemon=True,
+            name='ChemStation acquiring monitor'
         )
         self._killswitch = threading.Event()
         self.instances.append(self)
         self.always_search = always_search
         if self._all_started and autostart:
             self._monitor_thread.start()
+        # start the monitor thread
+        AcquisitionSearch._start_class_acquiring_monitor()
 
     def __eq__(self, other: Union[str, pathlib.Path, 'AcquisitionSearch']):
         if isinstance(other, AcquisitionSearch):
@@ -162,31 +168,60 @@ class AcquisitionSearch:
         """clears acquiring status if the instance is currently acquiring"""
         if self._acquiring_path is not None:
             self._acquiring_path = None
-            self._located.clear()
+
+    @classmethod
+    def _start_class_acquiring_monitor(cls):
+        """creates and starts the class acquiring monitor"""
+        if cls._monitor_thread is None:
+            cls._monitor_thread = threading.Thread(
+                target=cls._class_acquiring_monitor,
+                daemon=True,
+                name='ChemStation class acquiring monitor'
+            )
+            cls._monitor_thread.start()
+
+    @classmethod
+    def _class_acquiring_monitor(cls):
+        """
+        method which monitors instances of the class for located acquiring files. Using this method avoids
+        complicated shared-state modification from within instances.
+        """
+        logger.info('starting AcquisitionSearch monitor')
+        while True:
+            acquiring_instances = cls.acquiring_instances()
+            # profiles and checking the flag sate is ~8% faster than always setting or clearing
+            if len(acquiring_instances) > 0 and cls._located.is_set() is False:
+                cls._located.set()
+            elif len(acquiring_instances) == 0 and cls._located.is_set():
+                cls._located.clear()
+
+            # warning for multiple located instances
+            if len(acquiring_instances) > 1 and cls._multi_warn is False:
+                logger.warning(
+                    f'multiple matches for ACQUIRING.TXT were found in the chemstation data directories. '
+                    f'This usually results when ChemStation did not exit cleanly. Please locate and '
+                    f'remove the old acquiring file. '
+                )
+                cls._multi_warn = True
+            elif len(acquiring_instances) < 2 and cls._multi_warn is True:
+                cls._multi_warn = False
 
     def _acquiring_monitor(self):
         """
         Searches for and monitors acquiring files in the target directory.
         """
         while True:
-            if self._killswitch.isSet():
+            if self._killswitch.is_set():
                 self._clear_acquiring()
                 break
 
             # current instance does not have a path AND always search or another instance has not found a file
-            if self._acquiring_path is None and self.always_search or not self._located.is_set():
+            if self._acquiring_path is None and (self.always_search or self._located.is_set() is False):
                 # logger.debug('attempting to locate acquiring file')
                 acquiring_path = self.find_acquiring()
                 # if there is one file, update
                 if acquiring_path is not None:
                     logger.info('ACQUIRING.TXT located')
-                    if self._located.is_set():
-                        raise ValueError(
-                            f'multiple matches for ACQUIRING.TXT were found in the chemstation data directories. '
-                            f'This usually results when ChemStation did not exit cleanly. Please locate and '
-                            f'remove the old acquiring file. '
-                        )
-                    self._located.set()  # indicate that a file has been found
                     self._acquiring_path = acquiring_path
                     continue
 
@@ -201,10 +236,8 @@ class AcquisitionSearch:
                 if self._acquiring_path.is_file() is False:
                     logger.info('ACQUIRING.TXT disappeared')
                     self._acquiring_path = None
-                    self._located.clear()  # clear location flag
                     continue
 
-                # todo verify that this always works
                 # parse and retrieve current number and file
                 try:
                     self._current_number, self._current_file = self.current_num_and_file(self._acquiring_path)
@@ -212,6 +245,8 @@ class AcquisitionSearch:
                     logger.debug(e)
                     self._current_number = None
                     self._current_file = None
+                except Exception as e:
+                    logger.error(f'uncaught exception in acquiring monitor: {e}', exc_info=e)
 
             # wait cycle time
             time.sleep(self.cycle_time)
@@ -310,15 +345,27 @@ class AcquisitionSearch:
         # todo classproperty
         return cls._located.is_set()
 
+    @classmethod
+    def acquiring_instances(cls) -> List['AcquisitionSearch']:
+        """returns a list of acquiring instances"""
+        return [
+            instance
+            for instance in cls.instances
+            if instance.acquiring_path is not None
+        ]
+
     @classmethod
     def acquiring_instance(cls) -> 'AcquisitionSearch':
-        """retrieve the currently acquiring instance"""
+        """retrieve the currently acquiring instance. Only returns if and only if one instance is acquiring"""
         # todo classproperty
         if cls._located.is_set() is False:
             raise ValueError(f'No acquisition flag file has been identified')
-        for inst in cls.instances:
-            if inst.acquiring is True:
-                return inst
+        acquiring = cls.acquiring_instances()
+        if len(acquiring) > 1:
+            raise ValueError(
+                'multiple instances have been identified as acquiring, retrieval without context is not possible'
+            )
+        return acquiring[0]
 
     @classmethod
     def acquiring_instance_num_and_file(cls) -> Tuple[int, pathlib.Path]:
